@@ -7,7 +7,7 @@ sub new {
 }
 
 sub do {
-	my ($self, $genomei, @args) = @_;
+	my ($self, $genome, @args) = @_;
 
 	### &$self->{function}($genome)
 	return $self->{function}->($genome, @args);
