@@ -23,7 +23,9 @@ sub fittest_simple {
 	my $fitness = 0.0;
 
 	for (my $i = 0; $i < scalar $self->{population}; $i++) {
-		if ($self->{population}[$i]->fitness_simple > $fitness) {
+		my $f = $self->{population}[$i]->fitness_simple;
+		if ($f >= $fitness) {
+			$fitness = $f;
 			$fittest_genome = $self->{population}[$i];
 		}	
 	}
